#
# spec file for package pocketsphinx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor python%nil

%if "%flavor" == "python"
%define name_suffix -%{flavor}
%else
%define name_suffix %{nil}
%endif

%define sover 5
%define versuffix 5.0.3+git20241211.69167fb
Name:           pocketsphinx%{name_suffix}
Version:        5.0.3+git20241211.69167fb
Release:        1.2
Summary:        Speech recognizer library written in C
License:        BSD-2-Clause
Group:          Productivity/Office/Other
URL:            http://cmusphinx.sourceforge.net/wiki/download/
Source:         pocketsphinx-%{version}.tar.xz
Patch1:         fix-python-installation.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
%if "%flavor" == "python"
BuildRequires:  pocketsphinx-devel
BuildRequires:  python3
BuildRequires:  python3-Cython
BuildRequires:  python3-devel
BuildRequires:  python3-scikit-build-core
%endif
Obsoletes:      pocketsphinx5 <= 5
Provides:       pocketsphinx5 = %{version}

%description
Pocketsphinx is a version of the open-source CMU Sphinx II speech
recognition system which is able to recognize speech in real-time.

%package -n libpocketsphinx%{sover}
Summary:        Speech recognizer library
Group:          System/Libraries
Requires:       pocketsphinx

%description -n libpocketsphinx%{sover}
CMU Sphinx toolkit has a number of packages for different tasks and
applications. Pocketsphinx is a version of the open-source CMU Sphinx
II speech recognition system which is able to recognize speech in
real-time.

%package devel
Summary:        Development files for pocketsphinx, a speech recognizer library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Obsoletes:      pocketsphinx5-devel <= 5
Provides:       pocketsphinx5-devel = %{version}

%description devel
CMU Sphinx toolkit has a number of packages for different tasks and
applications. Pocketsphinx is a version of the open-source CMU Sphinx
II speech recognition system which is able to recognize speech in
real-time.

This is the development package for pocketsphinx.

%package -n python3-pocketsphinx
Summary:        Python bindings for pocketsphinx
Group:          Development/Languages/Python
Requires:       pocketsphinx = %{version}
Obsoletes:      python3-pocketsphinx5-python <= 5
Provides:       python3-pocketsphinx5 = %{version}

%description -n python3-pocketsphinx
Pocketsphinx is a version of the open-source CMU Sphinx II speech
recognition system which is able to recognize speech in real-time.

This package provides python bindings for pocketsphinx.

%package -n gstreamer-plugin-pocketsphinx
Summary:        GStreamer Plugin for pocketsphinx
Requires:       %{name} = %{version}

%description -n gstreamer-plugin-pocketsphinx
Pocketsphinx is a version of the open-source CMU Sphinx II speech
recognition system which is able to recognize speech in real-time.

This package provides the GStreamer plugin for pocketsphinx.

%prep
%setup -q -n pocketsphinx-%{version}
%autopatch -p1

%build
%cmake \
%if "%flavor" == "python"
    -DSKBUILD=1 \
    -DUSE_INSTALLED_POCKETSPHINX=1 \
%else
    -DBUILD_GSTREAMER=1 \
%endif
    %{nil}
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}

%ldconfig_scriptlets -n libpocketsphinx%{sover}

%if "%flavor" != "python"
%files
%doc AUTHORS README.md NEWS
%license LICENSE
%{_bindir}/pocketsphinx_batch
%{_bindir}/pocketsphinx
%{_bindir}/pocketsphinx_jsgf2fsg
%{_bindir}/pocketsphinx_lm_convert
%{_bindir}/pocketsphinx_lm_eval
%{_bindir}/pocketsphinx_mdef_convert
%{_bindir}/pocketsphinx_pitch
%dir %{_datadir}/pocketsphinx/
%dir %{_datadir}/pocketsphinx/model
%{_datadir}/pocketsphinx/model/en-us
%{_mandir}/man1/pocketsphinx*%{ext_man}
%{_mandir}/man1/sphinx*%{ext_man}

%files -n libpocketsphinx%{sover}
%{_libdir}/libpocketsphinx.so.%{sover}*

%files devel
%{_includedir}/pocketsphinx
%{_includedir}/pocketsphinx.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/pocketsphinx.pc

%files -n gstreamer-plugin-pocketsphinx
%{_libdir}/gstreamer-1.0/libgstpocketsphinx.so

%else

%files -n python3-pocketsphinx
%{python3_sitearch}/pocketsphinx

%endif

%changelog
* Wed Dec 18 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to 5.0.3:
  * This release mainly fixes building for Python 3.12, but also
    fixes a serious bug in the NGramModel wrapper class along the
    way. Note that Python 3.6 and 3.7 are no longer supported.
  * Switch to scikit-build-core and tox to fix many issues.
- Update to 5.0.2:
    Removed unnecessary shinxbase in package config
    Do not attempt to align phones to impossibly short durations (fixes #339)
    Require specific setuptools version to fix editable install (fixes: #353)
- Update to 5.0.1:
    Include examples of live recognition on various platforms
    Add missing close brace for C++
    Use a separate search for ps_set_align_text()
    Fix regression tests and -phone_align in main program
    Use trailing slash with include directory
    Removed unnecessary libpthread in package config
    fix: fix a stray #if WORDS_BIGENDIAN (fixes: #343)
- Update to 5.0.0. Includes among other these notable changes:
  * pocketsphinx_continuous is gone, replaced by plain old
    pocketsphinx, which is documented in the README file.
  * The configuration interface is now quite different. It is not a
    "command-line parser" anymore and the configuration parameters
    have lost their leading dashes.
  * All of the SphinxBase "utility" headers have also been made
    internal and their symbols will no longer be exported on
    Windows. Conversely, the JSGF and N-Gram language model API has
    been included in <pocketsphinx/model.h>.
  * The sphinx_fe and sphinx_cepview utilities have been moved to
    SphinxTrain.
  * The audio interface (<sphinxbase/ad.h>) has been removed.
  * The -remove_noise option is now controlled by the acoustic
    model as it needs to match the training.
  * The -remove_silence option has been removed as it is a Bad Idea
    and Considered Harmful for batch mode recognition. Please use
    the endpointer API as detailed in <pocketsphinx/endpointer.h>
    and examples/live.c or examples/live.py.
  * The -cmninit option is not controlled by the default acoustic
    model anymore. This may cause some problems for live
    recognition as the defaults may not match the feature
    extraction parameters.
  * The SWIG wrappers have been removed. Only Python 3 is directly
    supported as a dynamic language binding. Node.js may be
    supported in the near future. The C API is specifically
    designed to be easily supported through FFI, so you can do
    that.
  * Python support is much improved, fully documented, and builds a
    proper module directly from the (top level of the) source tree
    with pip or build.
  * Android support is gone but may come back (contributions
    welcome, I don't have time to support anything other than Linux
    on x86_64 and s390x)
  * Other changes:
  * Change the <pocketsphinx/search.h> API to be slightly more
    intuitive
  * New force-alignment API and two-pass alignment to get
    phone/state durations
  * Uniformize API and test fixed-point mode properly
  * Fix float-to-int underflows (#199, #252)
  * Disallow multiple search types in config or command-line
  * Revert incorrect optimizations to JSGF compiler (fixes #53)
  * Make seg_iter and hyp behave as expected in kws search
    (fixes #122)
  * feat: add -config and config to parse and save JSON
  * Resurrect GStreamer support
  * Remove sphinxbase and modernize configuration API
  * Add support for input files to pocketsphinx command line
  * Add compatibility with pocketsphinx-python 0.1.5
  * Rename pocketsphinx5 to pocketsphinx
  * Updated the en-us dict
  * Fix memory leak in allphone_search.c
  * Forward declare allphone_clear_segments in allphone_search.c
  * Make force alignment accessible from pocketsphinx_batch and
    the ps_decoder API
  * Improve linking for internal headers
  * Fix memory leak in bin_mdef_read_text
  * Large build system and small API modernizations
  * Fix windows build
  * Fix endianness issues in binary trie LM code
  * Build a proper Python package
  * Update -cmninit parameter when CMN is updated
  * Switch back to Cython and use scikit-build for Python module
  * Document Python module better and build ReadTheDocs with
    (the other) Sphinx
  * Fix install command for Mac and iOS builds
  * Incoporate WebRTC VAD code
  * Reorganize header files
  * Remove thread library
  * Add a proper API for cepstral mean normalization
  * Make -samprate an int after all these years
- Obsoletes the pocketsphinx5/sphinxbase/sphinxbase5 packages and
  remove the use of update-alternatives since it's not needed
  anymore.
- Add _service file.
- Add _multibuild to build the python package.
- Drop patches that don't seem to be needed anymore:
  * pocketsphinx-doxygen.patch
  * pocketsphinx-largefile.patch
  * pocketsphinx-long-utterance.patch
  * use-python3.patch
- Add patch to fix installation directory of python module:
  * fix-python-installation.patch
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Mar 26 2020 Antonio Larrosa <alarrosa@suse.com>
- Use update-alternatives for the man pages
- pocketsphinx-devel now conflicts with pocketsphinx5-devel
- python3-pocketsphinx now conflicts with python3-pocketsphinx5 and
  python3-pocketsphinx-python <= 0.1.3
- Fixes for symbol-not-found errors in the python3 port and a small fix
  to use python3 in another python call. Updated patch:
  * use-python3.patch
* Wed Mar 25 2020 Antonio Larrosa <alarrosa@suse.com>
- Generate python3 bindings instead of python2:
  * use-python3.patch
* Wed Feb 27 2019 Antonio Larrosa <alarrosa@suse.com>
- Add %%check section to run tests
* Sat Feb 23 2019 alarrosa@suse.com
- Use alternatives for binaries to make possible to have it coinstalled
  with pocketsphinx5 5prealpha
* Tue Aug 14 2018 jengelh@inai.de
- Fix RPM groups.
- Implement shared library packaging guideline.
* Sun Aug 12 2018 alarrosa@suse.com
- Use %%license for license file
* Mon Sep  4 2017 alarrosa@suse.com
- Update to version 0.8:
  * Improvements:
  * API is better exposed in Python, SWIG and gstreamer
  * New API for exact grammar match
  * Configurable type for the frame counter, allows utterances way longer
    than 5 minutes
  * Fixes:
  * Memory leaks, refcounting and other memory-related issues
  * Use proper word bounary senones for the words added on the fly
  * Accurate FSG lextree construction
- Add pocketsphinx-doxygen.patch, pocketsphinx-largefile.patch,
  pocketsphinx-long-utterance.patch to fix various issues. Patches obtained
  from the fedora package.
- Fixed license in spec file. It's BSD-2-Clause according to COPYING
- Run spec-cleaner
- Move the python bindings to a new python2-pocketsphinx package
* Sat Nov 10 2012 alinm.elena@gmail.com
- initial commit
